@@ -1,12 +1,10 @@
-import logging
 import argparse
 import sys
 import time
 from terminaltables import AsciiTable
 
 from studio import model
-
-logging.basicConfig()
+from studio.util import logs
 
 _my_logger = None
 
@@ -122,7 +120,7 @@ def _kill(args, cli_args):
 def get_logger():
     global _my_logger
     if not _my_logger:
-        _my_logger = logging.getLogger('studio-runs')
+        _my_logger = logs.get_logger('studio-runs')
     return _my_logger
 
 
