@@ -1,14 +1,10 @@
-import logging
 import os
 import json
 import time
-import google
-from google.gax.errors import RetryError
+from google.api_core.exceptions import RetryError
 
-from .model import parse_verbosity
-from .util import sixdecode, retry
-
-logging.basicConfig()
+from studio.util.util import sixdecode, retry, parse_verbosity, check_for_kb_interrupt
+from studio.util import logs
 
 
 class PubsubQueue(object):
@@ -20,7 +16,7 @@ class PubsubQueue(object):
             credentials = json.loads(f.read())
 
         project_name = credentials['project_id']
-        self.logger = logging.getLogger(self.__class__.__name__)
+        self.logger = logs.get_logger(self.__class__.__name__)
         if verbose is not None:
             self.logger.setLevel(parse_verbosity(verbose))
 
@@ -33,6 +29,7 @@ class PubsubQueue(object):
         try:
             self.pubtopic = self.pubclient.get_topic(self.topic_name)
         except BaseException as e:
+            check_for_kb_interrupt()
             self.pubtopic = self.pubclient.create_topic(self.topic_name)
             self.logger.info('topic {} created'.format(self.topic_name))
 
@@ -45,6 +42,7 @@ class PubsubQueue(object):
         try:
             self.subclient.get_subscription(self.sub_name)
         except BaseException as e:
+            check_for_kb_interrupt()
             self.logger.warn(e)
             self.subclient.create_subscription(self.sub_name, self.topic_name,
                                                ack_deadline_seconds=20)
@@ -145,6 +143,9 @@ class PubsubQueue(object):
         try:
             self.pubclient.delete_topic(self.topic_name)
             self.subclient.delete_subscription(self.sub_name)
-        except google.gax.errors.RetryError as e:
+        except RetryError as e:
             self.logger.error('Queue deletion failed with exception:')
             self.logger.exception(e)
+
+    def shutdown(self, delete_queue=True):
+        self.delete()
