@@ -9,19 +9,20 @@ import time
 import six
 import numpy as np
 
-from .credentials import KEY_CREDENTIALS
-from .hyperparameter import HyperparameterParser
-from .util import rand_string, Progbar, rsync_cp, check_for_kb_interrupt
-from .experiment import create_experiment
-from .experiment_submitter import submit_experiments
-from . import model
-from . import git_util
-from . import local_worker
-from . import fs_tracker
-from . import logs
+from studio.credentials.credentials import KEY_CREDENTIALS
+from studio.hyperparameter import HyperparameterParser
+from studio.extra_util import Progbar, rsync_cp
+from studio.experiments.experiment import create_experiment
+from studio.experiment_submitter import submit_experiments
+from studio import model
+from studio import git_util
+from studio import local_worker
+from studio import fs_tracker
+from studio.dependencies_policies.studio_dependencies_policy import StudioDependencyPolicy
+from studio.util import logs, util
 
 def main(args=sys.argv[1:]):
-    logger = logs.getLogger('studio-runner')
+    logger = logs.get_logger('studio-runner')
     parser = argparse.ArgumentParser(
         description='Studio runner. \
                      Usage: studio run <runner_arguments> \
@@ -269,6 +270,10 @@ def main(args=sys.argv[1:]):
     logger.debug(str(resources_needed))
 
     # Set up default artifacts:
+    # note that their "local" paths will be updated
+    # on Experiment creation,
+    # but they must have "local" field defined
+    # to have storage credentials set up properly.
     artifacts = {
         'workspace': {
             'mutable': False,
@@ -277,26 +282,32 @@ def main(args=sys.argv[1:]):
         },
         'modeldir': {
             'mutable': True,
+            'local': '',
             'unpack': True
         },
         'retval': {
             'mutable': True,
+            'local': '',
             'unpack': True
         },
         'output': {
             'mutable': True,
+            'local': '',
             'unpack': True
         },
         'tb': {
             'mutable': True,
+            'local': '',
             'unpack': True
         },
         '_metrics': {
             'mutable': True,
+            'local': '',
             'unpack': True
         },
         '_metadata': {
             'mutable': True,
+            'local': '',
             'unpack': True
         }
     }
@@ -421,13 +432,13 @@ def main(args=sys.argv[1:]):
                 try:
                     optimizer.tell(hyperparam_pop, fitnesses, behaviors)
                 except BaseException:
-                    check_for_kb_interrupt()
+                    util.check_for_kb_interrupt()
                     optimizer.tell(hyperparam_pop, fitnesses)
 
                 try:
                     optimizer.disp()
                 except BaseException:
-                    check_for_kb_interrupt()
+                    util.check_for_kb_interrupt()
                     logger.warn('Optimizer has no disp() method')
     else:
         if rerun:
@@ -451,6 +462,7 @@ def main(args=sys.argv[1:]):
                 resources_needed=resources_needed,
                 metric=runner_args.metric,
                 max_duration=runner_args.max_duration,
+                dependency_policy=StudioDependencyPolicy()
             )]
 
         queue = model.get_queue(
@@ -598,7 +610,7 @@ def get_experiment_fitnesses(experiments, optimizer, config, logger):
                                 raise
 
                         except BaseException:
-                            check_for_kb_interrupt()
+                            util.check_for_kb_interrupt()
                             if j not in bad_line_dicts[i]:
                                 logger.warn(
                                     'Experiment %s: error parsing or invalid'
@@ -615,7 +627,7 @@ def get_experiment_fitnesses(experiments, optimizer, config, logger):
                             fitness = float(line.rstrip().split(':')[1])
                             # assert fitness >= 0.0
                         except BaseException:
-                            check_for_kb_interrupt()
+                            util.check_for_kb_interrupt()
                             if j not in bad_line_dicts[i]:
                                 logger.warn(
                                     'Experiment %s: error parsing or invalid'
@@ -749,7 +761,7 @@ def _add_hyperparam_experiments(
         # experiment_names = {}
         for hyperparam_tuple in hyperparam_tuples:
             experiment_name = experiment_name_base
-            experiment_name += "__opt__%s__%s" % (rand_string(32),
+            experiment_name += "__opt__%s__%s" % (util.rand_string(32),
                                                   int(time.time()))
             experiment_name = experiment_name.replace('.', '_')
 
@@ -769,7 +781,7 @@ def _add_hyperparam_experiments(
 
             for param_name, param_value in six.iteritems(hyperparam_tuple):
                 if isinstance(param_value, np.ndarray):
-                    array_filepath = '/tmp/%s.npy' % rand_string(32)
+                    array_filepath = '/tmp/%s.npy' % util.rand_string(32)
                     np.save(array_filepath, param_value)
                     assert param_name not in current_artifacts
                     current_artifacts[param_name] = {'local': array_filepath,
@@ -799,6 +811,7 @@ def _add_hyperparam_experiments(
                 resources_needed=resources_needed,
                 metric=runner_args.metric,
                 max_duration=runner_args.max_duration,
+                dependency_policy=StudioDependencyPolicy()
             ))
         return experiments
 
